@@ -4,7 +4,6 @@ from django.conf import settings
 from django.contrib.postgres.fields import ArrayField
 from django.core.mail import EmailMessage as EmailMessage_, EmailMultiAlternatives
 from django.db import models
-from django.template.engine import Engine
 from django.db.transaction import atomic
 from django.utils.module_loading import import_string
 from django.utils.timezone import now
@@ -109,36 +108,37 @@ class EmailMessage(models.Model):
     class Meta:
         ordering = ("priority", "created_at")
 
-    def get_django_email_message(self):
-        kwargs = {
-            "from_email": self.from_email,
-            "to": self.to,
-            "bcc": self.bcc,
-            "headers": self.headers,
-            "cc": self.cc,
-            "reply_to": self.reply_to,
-
-            "subject": get_rendered_template_string(
-                self.subject, self.context
-            ),
-            "body": get_rendered_template_string(
-                self.plain_body, self.context
-            )
-        }
-
-        if html_body := get_rendered_template_string(
-            self.html_body,
-            self.context
-        ):
-            email_message = EmailMultiAlternatives(**kwargs)
-            email_message.attach_alternative(html_body, "text/html")
-        else:
-            return EmailMessage_(**kwargs)
-
-        return email_message
+    # def get_django_email_message(self):
+    #     kwargs = {
+    #         "from_email": self.from_email,
+    #         "to": self.to,
+    #         "bcc": self.bcc,
+    #         "headers": self.headers,
+    #         "cc": self.cc,
+    #         "reply_to": self.reply_to,
+    #
+    #         "subject": get_rendered_template_string(
+    #             self.subject, self.context
+    #         ),
+    #         "body": get_rendered_template_string(
+    #             self.plain_body, self.context
+    #         )
+    #     }
+    #
+    #     if html_body := get_rendered_template_string(
+    #         self.html_body,
+    #         self.context
+    #     ):
+    #         email_message = EmailMultiAlternatives(**kwargs)
+    #         email_message.attach_alternative(html_body, "text/html")
+    #     else:
+    #         return EmailMessage_(**kwargs)
+    #
+    #     return email_message
 
     def send(self) -> None:
-        self.get_django_email_message().send(self.fail_silently)
+        email_message = EmailMessage_(subject=self.subject, body=self.plain_body, to=self.to)
+        email_message.send(self.fail_silently)
 
     def process_sent(self, need_to_delete: bool) -> None:
         if need_to_delete:
